@@ -1,6 +1,6 @@
 /*----------------------------------------------------------------------------*/
 /*  CP2K: A general program to perform molecular dynamics simulations         */
-/*  Copyright 2000-2021 CP2K developers group <https://cp2k.org>              */
+/*  Copyright 2000-2022 CP2K developers group <https://cp2k.org>              */
 /*                                                                            */
 /*  SPDX-License-Identifier: BSD-3-Clause                                     */
 /*----------------------------------------------------------------------------*/
@@ -64,7 +64,7 @@ int main(int argc, char *argv[]) {
     return 1;
   }
 
-  offload_set_device_id(0);
+  offload_set_chosen_device(0);
   grid_library_init();
 
   const double max_diff =
