@@ -187,9 +187,12 @@ def process_file(fn, allow_modifications):
         run_local_tool("./tools/doxify/doxify.sh", fn)
         run_prettify(fn)
 
-    if re.match(r".*\.(c|cu|cpp|cc|h|hpp)$", fn):
+    if re.match(r".*\.(c|cu|h)$", fn):
         run_remote_tool("clangformat", fn)
 
+    if re.match(r".*\.(cc|cpp|cxx|hcc|hpp|hxx)$", fn):
+        raise Exception(f"C++ is not supported.")
+
     if re.match(r"(.*/PACKAGE)|(.*\.py)$", fn):
         ast.parse(orig_content, filename=fn)
         run_remote_tool("black", fn)
@@ -207,6 +210,9 @@ def process_file(fn, allow_modifications):
     if re.match(r"./data/.*POTENTIALS?$", fn):
         check_data_files()
 
+    if re.match(r".*/Makefile", fn):
+        run_local_tool("./tools/precommit/format_makefile.py", fn)
+
     run_check_file_properties(fn)
 
     new_content = Path(fn).read_bytes()
@@ -219,7 +225,7 @@ def process_file(fn, allow_modifications):
             orig_lines = orig_content.decode("utf8").split("\n")
             new_lines = new_content.decode("utf8").split("\n")
             diff = unified_diff(orig_lines, new_lines, "before", "after", lineterm="")
-        except:
+        except Exception:
             diff = []  #
         raise Exception(f"File modified:\n" + "\n".join(diff))
 
