@@ -1,17 +1,14 @@
 #!/bin/bash -e
 
 # TODO: Review and if possible fix shellcheck errors.
-# shellcheck disable=SC1003,SC1035,SC1083,SC1090
-# shellcheck disable=SC2001,SC2002,SC2005,SC2016,SC2091,SC2034,SC2046,SC2086,SC2089,SC2090
-# shellcheck disable=SC2124,SC2129,SC2144,SC2153,SC2154,SC2155,SC2163,SC2164,SC2166
-# shellcheck disable=SC2235,SC2237
+# shellcheck disable=all
 
 [ "${BASH_SOURCE[0]}" ] && SCRIPT_NAME="${BASH_SOURCE[0]}" || SCRIPT_NAME=$0
 SCRIPT_DIR="$(cd "$(dirname "$SCRIPT_NAME")" && pwd -P)"
 
 # +---------------------------------------------------------------------------+
 # |   CP2K: A general program to perform molecular dynamics simulations       |
-# |   Copyright 2000-2021 CP2K developers group <https://cp2k.org>            |
+# |   Copyright 2000-2022 CP2K developers group <https://cp2k.org>            |
 # |                                                                           |
 # |   SPDX-License-Identifier: GPL-2.0-or-later                               |
 # +---------------------------------------------------------------------------+
@@ -22,6 +19,7 @@ SCRIPT_DIR="$(cd "$(dirname "$SCRIPT_NAME")" && pwd -P)"
 #>           libraries CP2K depends on and generate a set of ARCH files which
 #>           can be used to compile CP2K
 #> \history  Created on Friday, 2016/02/05
+#            Update for Intel (17.01.2022, MK)
 #> \author   Lianheng Tong (ltong) lianheng.tong@kcl.ac.uk
 # *****************************************************************************
 
@@ -84,8 +82,8 @@ OPTIONS:
                           --with-PKG option placed AFTER this option on the
                           command line.
 --mpi-mode                Selects which MPI flavour to use. Available options
-                          are: mpich, openmpi, intelmpi, and no. By selecting no,
-                          you will be disabling MPI support. By default the script
+                          are: mpich, openmpi, intelmpi, and no. By selecting "no",
+                          MPI is not supported and disabled. By default the script
                           will try to determine the flavour based on the MPI library
                           currently available in your system path. For CRAY (CLE)
                           systems, the default flavour is mpich. Note that explicitly
@@ -93,20 +91,25 @@ OPTIONS:
                           options to values other than no will also switch --mpi-mode
                           to the respective mode.
 --math-mode               Selects which core math library to use. Available options
-                          are: acml, cray, mkl, and openblas. cray
+                          are: acml, cray, mkl, and openblas. The option "cray"
                           corresponds to cray libsci, and is the default for CRAY
                           (CLE) systems. For non-CRAY systems, if env variable MKLROOT
                           exists then mkl will be default, otherwise openblas is the
-                          default option. Explicitly setting
-                          --with-acml, --with-mkl or --with-openblas options will
-                          switch --math-mode to the respective modes.
+                          default option. Explicitly setting --with-acml, --with-mkl,
+                          or --with-openblas options will switch --math-mode to the
+                          respective modes.
 --gpu-ver                 Selects the GPU architecture for which to compile. Available
-                          options are: K20X, K40, K80, P100, V100, Mi50, Mi100, no. Default: no.
-                          The script will determine the correct corresponding value for
-                          nvcc's '-arch' flag.
+                          options are: K20X, K40, K80, P100, V100, Mi50, Mi100, and no.
+                          This setting determines the value of nvcc's '-arch' flag.
+                          Default = no.
 --libint-lmax             Maximum supported angular momentum by libint.
                           Higher values will increase build time and library size.
                           Default = 5
+--log-lines               Number of log file lines dumped in case of a non-zero exit code.
+                          Default = 200
+--generic                 Compile for a generic target system, i.e. do not optimize for
+                          the actual host system.
+--no-arch-files           Do not generate arch files
 --dry-run                 Write only config files, but don't actually build packages.
 
 The --enable-FEATURE options follow the rules:
@@ -123,10 +126,15 @@ The --enable-FEATURE options follow the rules:
                           this option forces the master development version
                           to be installed.
                           Default = no
-  --enable-cuda           Turn on GPU (CUDA) support.
+  --enable-cuda           Turn on GPU (CUDA) support (can be combined
+                          with --enable-opencl).
                           Default = no
   --enable-hip            Turn on GPU (HIP) support.
                           Default = no
+  --enable-opencl         Turn on OpenCL (GPU) support. Requires the OpenCL
+                          development packages and runtime. If combined with
+                          --enable-cuda, OpenCL alongside of CUDA is used.
+                          Default = no
   --enable-cray           Turn on or off support for CRAY Linux Environment
                           (CLE) manually. By default the script will automatically
                           detect if your system is CLE, and provide support
@@ -145,12 +153,13 @@ The --with-PKG options follow the rules:
   --with-PKG              The option keyword alone will be equivalent to
                           --with-PKG=install
 
-  --with-gcc              The GCC compiler to use to compile CP2K
+  --with-gcc              The GCC compiler to use to compile CP2K.
+                          Default = system
+  --with-intel            Use the Intel compiler to compile CP2K.
                           Default = system
   --with-cmake            Cmake utilities
                           Default = install
-  --with-openmpi          OpenMPI, important if you want parallel version
-                          of CP2K.
+  --with-openmpi          OpenMPI, important if you want parallel version of CP2K.
                           Default = system
   --with-mpich            MPICH, MPI library like OpenMPI. one should
                           use only one of OpenMPI, MPICH or Intel MPI.
@@ -179,15 +188,7 @@ The --with-PKG options follow the rules:
   --with-scalapack        Parallel linear algebra library, needed for parallel
                           calculations.
                           Default = install
-  --with-libsmm           CP2K's own small matrix multiplication library. An optimised
-                          libsmm should increase the code performance. If you set
-                          --with-libsmm=install, then instead of actually compiling
-                          the library (which may take a long time), the script will
-                          try to download a preexisting version from the CP2K website
-                          that is compatible with your system.
-                          Default = no
-  --with-libxsmm          Small matrix multiplication library. If the system architecture
-                          is x86_64, then LIBXSMM can be used instead of libsmm.
+  --with-libxsmm          Small matrix multiplication library.
                           Default = install
   --with-elpa             Eigenvalue SoLvers for Petaflop-Applications library.
                           Fast library for large parallel jobs.
@@ -254,18 +255,18 @@ EOF
 # PACKAGE LIST: register all new dependent tools and libs here. Order
 # is important, the first in the list gets installed first
 # ------------------------------------------------------------------------
-tool_list="gcc cmake"
+tool_list="gcc intel cmake"
 mpi_list="mpich openmpi intelmpi"
 math_list="mkl acml openblas"
-lib_list="fftw libint libxc libsmm libxsmm cosma scalapack elpa plumed \
+lib_list="fftw libint libxc libxsmm cosma scalapack elpa plumed \
           spfft spla ptscotch superlu pexsi quip gsl spglib hdf5 libvdwxc sirius
           libvori"
-package_list="$tool_list $mpi_list $math_list $lib_list"
+package_list="${tool_list} ${mpi_list} ${math_list} ${lib_list}"
 # ------------------------------------------------------------------------
 
 # first set everything to __DONTUSE__
-for ii in $package_list; do
-  eval with_${ii}=__DONTUSE__
+for ii in ${package_list}; do
+  eval with_${ii}="__DONTUSE__"
 done
 
 # ------------------------------------------------------------------------
@@ -273,26 +274,26 @@ done
 # ------------------------------------------------------------------------
 
 # tools to turn on by default:
-with_gcc=__SYSTEM__
+with_gcc="__SYSTEM__"
 
 # libs to turn on by default, the math and mpi libraries are chosen by there respective modes:
-with_fftw=__INSTALL__
-with_libint=__INSTALL__
-with_libxsmm=__INSTALL__
-with_libxc=__INSTALL__
-with_scalapack=__INSTALL__
+with_fftw="__INSTALL__"
+with_libint="__INSTALL__"
+with_libxsmm="__INSTALL__"
+with_libxc="__INSTALL__"
+with_scalapack="__INSTALL__"
 # default math library settings, MATH_MODE picks the math library
 # to use, and with_* defines the default method of installation if it
 # is picked. For non-CRAY systems defaults to mkl if $MKLROOT is
 # available, otherwise defaults to openblas
-if [ "$MKLROOT" ]; then
-  export MATH_MODE=mkl
+if [ "${MKLROOT}" ]; then
+  export MATH_MODE="mkl"
+  with_mkl="__SYSTEM__"
 else
-  export MATH_MODE=openblas
+  export MATH_MODE="openblas"
 fi
-with_acml=__SYSTEM__
-with_mkl=__SYSTEM__
-with_openblas=__INSTALL__
+with_acml="__SYSTEM__"
+with_openblas="__INSTALL__"
 
 # sirius is activated by default
 with_sirius="__INSTALL__"
@@ -306,94 +307,108 @@ with_spla="__DONTUSE__"
 with_cosma="__INSTALL__"
 with_libvori="__INSTALL__"
 # for MPI, we try to detect system MPI variant
-with_openmpi="__SYSTEM__"
-with_mpich="__SYSTEM__"
-with_intelmpi="__SYSTEM__"
 if (command -v mpirun >&- 2>&-); then
   # check if we are dealing with openmpi, mpich or intelmpi
   if (mpirun --version 2>&1 | grep -s -q "HYDRA"); then
     echo "MPI is detected and it appears to be MPICH"
-    export MPI_MODE=mpich
+    export MPI_MODE="mpich"
+    with_mpich="__SYSTEM__"
   elif (mpirun --version 2>&1 | grep -s -q "Open MPI"); then
     echo "MPI is detected and it appears to be OpenMPI"
-    export MPI_MODE=openmpi
+    export MPI_MODE="openmpi"
+    with_openmpi="__SYSTEM__"
   elif (mpirun --version 2>&1 | grep -s -q "Intel"); then
     echo "MPI is detected and it appears to be Intel MPI"
-    with_gcc=__DONTUSE__
-    export MPI_MODE=intelmpi
+    with_gcc="__DONTUSE__"
+    with_intel="__SYSTEM__"
+    with_intelmpi="__SYSTEM__"
+    export MPI_MODE="intelmpi"
   else # default to mpich
     echo "MPI is detected and defaults to MPICH"
-    export MPI_MODE=mpich
+    export MPI_MODE="mpich"
+    with_mpich="__SYSTEM__"
   fi
 else
   report_warning $LINENO "No MPI installation detected (ignore this message in Cray Linux Environment or when MPI installation was requested)."
-  export MPI_MODE=no
+  export MPI_MODE="no"
 fi
 
 # default enable options
-dry_run=__FALSE__
-enable_tsan=__FALSE__
-enable_gcc_master=__FALSE__
-enable_libxsmm_master=__FALSE__
-enable_cuda=__FALSE__
-enable_hip=__FALSE__
-export GPUVER=no
+dry_run="__FALSE__"
+no_arch_files="__FALSE__"
+export generic="__FALSE__"
+enable_tsan="__FALSE__"
+enable_gcc_master="__FALSE__"
+enable_libxsmm_master="__FALSE__"
+enable_opencl="__FALSE__"
+enable_cuda="__FALSE__"
+enable_hip="__FALSE__"
+export GPUVER="no"
 
 # default for libint
-export LIBINT_LMAX=5
+export LIBINT_LMAX="5"
+
+# default for log file dump size
+export LOG_LINES="200"
 
 # defaults for CRAY Linux Environment
-if [ "$CRAY_LD_LIBRARY_PATH" ]; then
-  enable_cray=__TRUE__
-  export MATH_MODE=cray
+if [ "${CRAY_LD_LIBRARY_PATH}" ]; then
+  enable_cray="__TRUE__"
+  export MATH_MODE="cray"
   # Default MPI used by CLE is assumed to be MPICH, in any case
-  # don't use the installers for the MPI libraries
+  # do not use the installers for the MPI libraries
   with_mpich="__DONTUSE__"
   with_openmpi="__DONTUSE__"
   with_intelmpi="__DONTUSE__"
-  export MPI_MODE=mpich
+  export MPI_MODE="mpich"
   # set default value for some installers appropriate for CLE
   with_gcc="__DONTUSE__"
+  with_intel="__DONTUSE__"
   with_fftw="__SYSTEM__"
   with_scalapack="__DONTUSE__"
 else
-  enable_cray=__FALSE__
+  enable_cray="__FALSE__"
 fi
 
 # ------------------------------------------------------------------------
 # parse user options
 # ------------------------------------------------------------------------
 while [ $# -ge 1 ]; do
-  case $1 in
+  case ${1} in
     -j)
       shift
-      export NPROCS_OVERWRITE=$1
+      export NPROCS_OVERWRITE="${1}"
+      ;;
+    -j[0-9]*)
+      export NPROCS_OVERWRITE="${1#-j}"
       ;;
     --no-check-certificate)
       export DOWNLOADER_FLAGS="-n"
       ;;
     --install-all)
-      # set all package to __INSTALL__ status
-      for ii in $package_list; do
-        eval with_${ii}=__INSTALL__
+      # set all package to the default installation status
+      for ii in ${package_list}; do
+        if [ "${ii}" != "intel" ] && [ "${ii}" != "intelmpi" ]; then
+          eval with_${ii}="__INSTALL__"
+        fi
       done
-      # default mpi-mode to MPICH
-      export MPI_MODE=mpich
+      # Use MPICH as default
+      export MPI_MODE="mpich"
       ;;
     --mpi-mode=*)
       user_input="${1#*=}"
       case "$user_input" in
         mpich)
-          export MPI_MODE=mpich
+          export MPI_MODE="mpich"
           ;;
         openmpi)
-          export MPI_MODE=openmpi
+          export MPI_MODE="openmpi"
           ;;
         intelmpi)
-          export MPI_MODE=intelmpi
+          export MPI_MODE="intelmpi"
           ;;
         no)
-          export MPI_MODE=no
+          export MPI_MODE="no"
           ;;
         *)
           report_error ${LINENO} \
@@ -406,16 +421,16 @@ while [ $# -ge 1 ]; do
       user_input="${1#*=}"
       case "$user_input" in
         cray)
-          export MATH_MODE=cray
+          export MATH_MODE="cray"
           ;;
         mkl)
-          export MATH_MODE=mkl
+          export MATH_MODE="mkl"
           ;;
         acml)
-          export MATH_MODE=acml
+          export MATH_MODE="acml"
           ;;
         openblas)
-          export MATH_MODE=openblas
+          export MATH_MODE="openblas"
           ;;
         *)
           report_error ${LINENO} \
@@ -425,66 +440,51 @@ while [ $# -ge 1 ]; do
       ;;
     --gpu-ver=*)
       user_input="${1#*=}"
-      case "$user_input" in
-        K20X)
-          export GPUVER=K20X
-          ;;
-        K40)
-          export GPUVER=K40
-          ;;
-        K80)
-          export GPUVER=K80
-          ;;
-        P100)
-          export GPUVER=P100
-          ;;
-        V100)
-          export GPUVER=V100
-          ;;
-        A100)
-          export GPUVER=A100
-          ;;
-        Mi50)
-          export GPUVER=Mi50
-          ;;
-        Mi100)
-          export GPUVER=Mi100
-          ;;
-        no)
-          export GPUVER=no
+      case "${user_input}" in
+        K20X | K40 | K80 | P100 | V100 | A100 | Mi50 | Mi100 | no)
+          export GPUVER="${user_input}"
           ;;
         *)
-          export GPUVER=no
           report_error ${LINENO} \
-            "--gpu-ver currently only supports K20X, K40, K80, P100, V100, A100, Mi50, Mi100 and no as options"
+            "--gpu-ver currently only supports K20X, K40, K80, P100, V100, A100, Mi50, Mi100, and no as options"
           exit 1
           ;;
       esac
       ;;
+    --log-lines=*)
+      user_input="${1#*=}"
+      export LOG_LINES="${user_input}"
+      ;;
     --libint-lmax=*)
       user_input="${1#*=}"
-      export LIBINT_LMAX="$user_input"
+      export LIBINT_LMAX="${user_input}"
+      ;;
+    --no-arch-files)
+      no_arch_files="__TRUE__"
+      ;;
+    --generic)
+      export generic="__TRUE__"
       ;;
     --dry-run)
       dry_run="__TRUE__"
       ;;
     --enable-tsan*)
       enable_tsan=$(read_enable $1)
-      if [ $enable_tsan = "__INVALID__" ]; then
+      if [ "${enable_tsan}" = "__INVALID__" ]; then
         report_error "invalid value for --enable-tsan, please use yes or no"
         exit 1
       fi
       ;;
     --enable-gcc-master*)
       enable_gcc_master=$(read_enable $1)
-      if [ $enable_gcc_master = "__INVALID__" ]; then
+      if [ "${enable_gcc_master}" = "__INVALID__" ]; then
         report_error "invalid value for --enable-gcc-master, please use yes or no"
         exit 1
       fi
       ;;
     --enable-libxsmm-master*)
       enable_libxsmm_master=$(read_enable $1)
-      if [ $enable_libxsmm_master = "__INVALID__" ]; then
+      if [ "${enable_libxsmm_master}" = "__INVALID__" ]; then
         report_error "invalid value for --enable-libxsmm-master, please use yes or no"
         exit 1
       fi
@@ -498,122 +498,129 @@ while [ $# -ge 1 ]; do
       ;;
     --enable-hip*)
       enable_hip=$(read_enable $1)
-      if [ $enable_hip = "__INVALID__" ]; then
+      if [ "${enable_hip}" = "__INVALID__" ]; then
         report_error "invalid value for --enable-hip, please use yes or no"
         exit 1
       fi
       ;;
+    --enable-opencl*)
+      enable_opencl=$(read_enable $1)
+      if [ $enable_opencl = "__INVALID__" ]; then
+        report_error "invalid value for --enable-opencl, please use yes or no"
+        exit 1
+      fi
+      ;;
     --enable-cray*)
       enable_cray=$(read_enable $1)
-      if [ $enable_cray = "__INVALID__" ]; then
+      if [ "${enable_cray}" = "__INVALID__" ]; then
         report_error "invalid value for --enable-cray, please use yes or no"
         exit 1
       fi
       ;;
     --with-gcc*)
-      with_gcc=$(read_with $1)
+      with_gcc=$(read_with "${1}")
       ;;
     --with-cmake*)
-      with_cmake=$(read_with $1)
+      with_cmake=$(read_with "${1}")
       ;;
     --with-mpich*)
-      with_mpich=$(read_with $1)
-      if [ $with_mpich != __DONTUSE__ ]; then
+      with_mpich=$(read_with "${1}")
+      if [ "${with_mpich}" != "__DONTUSE__" ]; then
         export MPI_MODE=mpich
       fi
       ;;
     --with-openmpi*)
-      with_openmpi=$(read_with $1)
-      if [ $with_openmpi != __DONTUSE__ ]; then
+      with_openmpi=$(read_with "${1}")
+      if [ "${with_openmpi}" != "__DONTUSE__" ]; then
         export MPI_MODE=openmpi
       fi
       ;;
     --with-intelmpi*)
-      with_intelmpi=$(read_with $1)
-      if [ $with_intelmpi != __DONTUSE__ ]; then
+      with_intelmpi=$(read_with "${1}" "__SYSTEM__")
+      if [ "${with_intelmpi}" != "__DONTUSE__" ]; then
         export MPI_MODE=intelmpi
       fi
       ;;
+    --with-intel*)
+      with_intel=$(read_with "${1}" "__SYSTEM__")
+      ;;
     --with-libint*)
-      with_libint=$(read_with $1)
+      with_libint=$(read_with "${1}")
       ;;
     --with-libxc*)
-      with_libxc=$(read_with $1)
+      with_libxc=$(read_with "${1}")
       ;;
     --with-fftw*)
-      with_fftw=$(read_with $1)
+      with_fftw=$(read_with "${1}")
       ;;
     --with-mkl*)
-      with_mkl=$(read_with $1)
-      if [ $with_mkl != __DONTUSE__ ]; then
-        export MATH_MODE=mkl
+      with_mkl=$(read_with "${1}" "__SYSTEM__")
+      if [ "${with_mkl}" != "__DONTUSE__" ]; then
+        export MATH_MODE="mkl"
       fi
       ;;
     --with-acml*)
-      with_acml=$(read_with $1)
-      if [ $with_acml != __DONTUSE__ ]; then
-        export MATH_MODE=acml
+      with_acml=$(read_with "${1}")
+      if [ "${with_acml}" != "__DONTUSE__" ]; then
+        export MATH_MODE="acml"
       fi
       ;;
     --with-openblas*)
-      with_openblas=$(read_with $1)
-      if [ $with_openblas != __DONTUSE__ ]; then
-        export MATH_MODE=openblas
+      with_openblas=$(read_with "${1}")
+      if [ "${with_openblas}" != "__DONTUSE__" ]; then
+        export MATH_MODE="openblas"
       fi
       ;;
     --with-scalapack*)
-      with_scalapack=$(read_with $1)
-      ;;
-    --with-libsmm*)
-      with_libsmm=$(read_with $1)
+      with_scalapack=$(read_with "${1}")
       ;;
     --with-libxsmm*)
-      with_libxsmm=$(read_with $1)
+      with_libxsmm=$(read_with "${1}")
       ;;
     --with-elpa*)
-      with_elpa=$(read_with $1)
+      with_elpa=$(read_with "${1}")
       ;;
     --with-ptscotch*)
-      with_ptscotch=$(read_with $1)
+      with_ptscotch=$(read_with "${1}")
       ;;
     --with-superlu*)
-      with_superlu=$(read_with $1)
+      with_superlu=$(read_with "${1}")
       ;;
     --with-pexsi*)
-      with_pexsi=$(read_with $1)
+      with_pexsi=$(read_with "${1}")
       ;;
     --with-quip*)
-      with_quip=$(read_with $1)
+      with_quip=$(read_with "${1}")
       ;;
     --with-plumed*)
-      with_plumed=$(read_with $1)
+      with_plumed=$(read_with "${1}")
       ;;
     --with-sirius*)
-      with_sirius=$(read_with $1)
+      with_sirius=$(read_with "${1}")
       ;;
     --with-gsl*)
-      with_gsl=$(read_with $1)
+      with_gsl=$(read_with "${1}")
       ;;
     --with-spglib*)
-      with_spglib=$(read_with $1)
+      with_spglib=$(read_with "${1}")
       ;;
     --with-hdf5*)
-      with_hdf5=$(read_with $1)
+      with_hdf5=$(read_with "${1}")
       ;;
     --with-libvdwxc*)
-      with_libvdwxc=$(read_with $1)
+      with_libvdwxc=$(read_with "${1}")
       ;;
     --with-spfft*)
-      with_spfft=$(read_with $1)
+      with_spfft=$(read_with "${1}")
       ;;
     --with-cosma*)
-      with_cosma=$(read_with $1)
+      with_cosma=$(read_with "${1}")
       ;;
     --with-libvori*)
-      with_libvori=$(read_with $1)
+      with_libvori=$(read_with "${1}")
       ;;
     --with-spla*)
-      with_spla=$(read_with $1)
+      with_spla=$(read_with "${1}")
       ;;
     --help*)
       show_help
@@ -632,128 +639,167 @@ while [ $# -ge 1 ]; do
 done
 
 # consolidate settings after user input
-export ENABLE_TSAN=$enable_tsan
-export ENABLE_CUDA=$enable_cuda
-export ENABLE_HIP=$enable_hip
-export ENABLE_CRAY=$enable_cray
-[ "$enable_gcc_master" = "__TRUE__" ] && export gcc_ver=master
-[ "$enable_libxsmm_master" = "__TRUE__" ] && export libxsmm_ver=master
+export ENABLE_TSAN="${enable_tsan}"
+export ENABLE_CUDA="${enable_cuda}"
+export ENABLE_HIP="${enable_hip}"
+export ENABLE_OPENCL="${enable_opencl}"
+export ENABLE_CRAY="${enable_cray}"
+[ "${enable_gcc_master}" = "__TRUE__" ] && export gcc_ver="master"
+[ "${enable_libxsmm_master}" = "__TRUE__" ] && export libxsmm_ver="master"
 
 # ------------------------------------------------------------------------
 # Check and solve known conflicts before installations proceed
 # ------------------------------------------------------------------------
-
-# mpi library conflicts
-if [ $MPI_MODE = no ]; then
-  if [ "$with_scalapack" != "__DONTUSE__" ]; then
+# Compiler conflicts
+if [ "${with_intel}" != "__DONTUSE__" ] && [ "${with_gcc}" = "__INSTALL__" ]; then
+  echo "You have chosen to use the Intel compiler, therefore the installation of the GCC compiler will be skipped."
+  with_gcc="__SYSTEM__"
+fi
+# MPI library conflicts
+if [ "${MPI_MODE}" = "no" ]; then
+  if [ "${with_scalapack}" != "__DONTUSE__" ]; then
     echo "Not using MPI, so scalapack is disabled."
     with_scalapack="__DONTUSE__"
   fi
-  if [ "$with_elpa" != "__DONTUSE__" ]; then
+  if [ "${with_elpa}" != "__DONTUSE__" ]; then
     echo "Not using MPI, so ELPA is disabled."
     with_elpa="__DONTUSE__"
   fi
-  if [ "$with_pexi" != "__DONTUSE__" ]; then
+  if [ "${with_pexsi}" != "__DONTUSE__" ]; then
     echo "Not using MPI, so PEXSI is disabled."
     with_pexsi="__DONTUSE__"
   fi
-  if [ "$with_sirius" != "__DONTUSE__" ]; then
+  if [ "${with_sirius}" != "__DONTUSE__" ]; then
     echo "Not using MPI, so sirius is disabled"
     with_sirius="__DONTUSE__"
   fi
-  if [ "$with_spfft" != "__DONTUSE__" ]; then
+  if [ "${with_spfft}" != "__DONTUSE__" ]; then
     echo "Not using MPI, so spfft is disabled"
     with_spfft="__DONTUSE__"
   fi
-  if [ "$with_spla" != "__DONTUSE__" ]; then
+  if [ "${with_spla}" != "__DONTUSE__" ]; then
     echo "Not using MPI, so spla is disabled"
     with_spla="__DONTUSE__"
   fi
-  if [ "$with_cosma" != "__DONTUSE__" ]; then
+  if [ "${with_cosma}" != "__DONTUSE__" ]; then
     echo "Not using MPI, so cosma is disabled"
     with_cosma="__DONTUSE__"
   fi
 else
   # if gcc is installed, then mpi needs to be installed too
-  if [ "$with_gcc" = "__INSTALL__" ]; then
-    echo "You have chosen to install GCC, therefore MPI libraries will have to be installed too"
-    with_openmpi="__INSTALL__"
-    with_mpich="__INSTALL__"
+  if [ "${with_gcc}" = "__INSTALL__" ]; then
+    echo "You have chosen to install the GCC compiler, therefore MPI libraries have to be installed too"
+    case ${MPI_MODE} in
+      mpich)
+        with_mpich="__INSTALL__"
+        with_openmpi="__DONTUSE__"
+        ;;
+      openmpi)
+        with_mpich="__DONTUSE__"
+        with_openmpi="__INSTALL__"
+        ;;
+    esac
+    echo "and the use of the Intel compiler and Intel MPI will be disabled."
+    with_intel="__DONTUSE__"
     with_intelmpi="__DONTUSE__"
   fi
+  # Enable only one MPI implementation
+  case ${MPI_MODE} in
+    mpich)
+      with_openmpi="__DONTUSE__"
+      with_intelmpi="__DONTUSE__"
+      ;;
+    openmpi)
+      with_mpich="__DONTUSE__"
+      with_intelmpi="__DONTUSE__"
+      ;;
+    intelmpi)
+      with_mpich="__DONTUSE__"
+      with_openmpi="__DONTUSE__"
+      ;;
+  esac
 fi
 
 # If CUDA or HIP are enabled, make sure the GPU version has been defined.
-if [ $ENABLE_CUDA = __TRUE__ ] || [ $ENABLE_HIP = __TRUE__ ]; then
-  if [ "$GPUVER" = no ]; then
+if [ "${ENABLE_CUDA}" = "__TRUE__" ] || [ "${ENABLE_HIP}" = "__TRUE__" ]; then
+  if [ "${GPUVER}" = "no" ]; then
     report_error "Please choose GPU architecture to compile for with --gpu-ver"
     exit 1
   fi
 fi
 
-# PESXI and its dependencies
-if [ "$with_pexsi" = "__DONTUSE__" ]; then
-  if [ "$with_ptscotch" != "__DONTUSE__" ]; then
+# If OpenCL is enabled, make sure LIBXSMM is enabled as well.
+if [ "${ENABLE_OPENCL}" = "__TRUE__" ]; then
+  if [ "${with_libxsmm}" = "__DONTUSE__" ]; then
+    report_error "LIBXSMM is necessary for the OpenCL backend (--with-libxsmm)"
+    exit 1
+  fi
+fi
+
+# PEXSI and its dependencies
+if [ "${with_pexsi}" = "__DONTUSE__" ]; then
+  if [ "${with_ptscotch}" != "__DONTUSE__" ]; then
     echo "Not using PEXSI, so PT-Scotch is disabled."
     with_ptscotch="__DONTUSE__"
   fi
-  if [ "$with_superlu" != "__DONTUSE__" ]; then
+  if [ "${with_superlu}" != "__DONTUSE__" ]; then
     echo "Not using PEXSI, so SuperLU-DIST is disabled."
     with_superlu="__DONTUSE__"
   fi
-elif [ "$with_pexsi" = "__INSTALL__" ]; then
-  [ "$with_ptscotch" = "__DONTUSE__" ] && with_ptscotch="__INSTALL__"
-  [ "$with_superlu" = "__DONTUSE__" ] && with_superlu="__INSTALL__"
+elif [ "${with_pexsi}" = "__INSTALL__" ]; then
+  [ "${with_ptscotch}" = "__DONTUSE__" ] && with_ptscotch="__INSTALL__"
+  [ "${with_superlu}" = "__DONTUSE__" ] && with_superlu="__INSTALL__"
 else
-  if [ "$with_ptscotch" = "__DONTUSE__" ]; then
+  if [ "${with_ptscotch}" = "__DONTUSE__" ]; then
     report_error "For PEXSI to work you need a working PT-Scotch library use --with-ptscotch option to specify if you wish to install the library or specify its location."
     exit 1
   fi
-  if [ "$with_superlu" = "__DONTUSE__" ]; then
+  if [ "${with_superlu}" = "__DONTUSE__" ]; then
     report_error "For PEXSI to work you need a working SuperLU-DIST library use --with-superlu option to specify if you wish to install the library or specify its location."
     exit 1
   fi
 fi
 
 # several packages require cmake.
-if [ "$with_spglib" = "__INSTALL__" ] ||
-  [ "$with_libvori" = "__INSTALL__" ] ||
-  [ "$with_scalapack" = "__INSTALL__" ] ||
-  [ "$with_superlu" = "__INSTALL__" ] ||
-  [ "$with_sirius" = "__INSTALL__" ] ||
-  [ "$with_cosma" = "__INSTALL__" ] ||
-  [ "$with_spfft" = "__INSTALL__" ] ||
-  [ "$with_spla" = "__INSTALL__" ]; then
-  [ "$with_cmake" = "__DONTUSE__" ] && with_cmake="__INSTALL__"
+if [ "${with_spglib}" = "__INSTALL__" ] ||
+  [ "${with_libvori}" = "__INSTALL__" ] ||
+  [ "${with_scalapack}" = "__INSTALL__" ] ||
+  [ "${with_superlu}" = "__INSTALL__" ] ||
+  [ "${with_sirius}" = "__INSTALL__" ] ||
+  [ "${with_cosma}" = "__INSTALL__" ] ||
+  [ "${with_spfft}" = "__INSTALL__" ] ||
+  [ "${with_spla}" = "__INSTALL__" ]; then
+  [ "${with_cmake}" = "__DONTUSE__" ] && with_cmake="__INSTALL__"
 fi
 
 # SIRIUS dependencies. Remove the gsl library from the dependencies if SIRIUS is not activated
-if [ "$with_sirius" = "__INSTALL__" ]; then
-  [ "$with_spfft" = "__DONTUSE__" ] && with_spfft="__INSTALL__"
-  [ "$with_spla" = "__DONTUSE__" ] && with_spla="__INSTALL__"
-  [ "$with_gsl" = "__DONTUSE__" ] && with_gsl="__INSTALL__"
-  [ "$with_libxc" = "__DONTUSE__" ] && with_libxc="__INSTALL__"
-  [ "$with_fftw" = "__DONTUSE__" ] && with_fftw="__INSTALL__"
-  [ "$with_spglib" = "__DONTUSE__" ] && with_spglib="__INSTALL__"
-  [ "$with_hdf5" = "__DONTUSE__" ] && with_hdf5="__INSTALL__"
-#  [ "$with_libvdwxc" = "__DONTUSE__" ] && with_libvdwxc="__INSTALL__"
-#  [ "$with_cosma" = "__DONTUSE__" ] && with_cosma="__INSTALL__"
+if [ "${with_sirius}" = "__INSTALL__" ]; then
+  [ "${with_spfft}" = "__DONTUSE__" ] && with_spfft="__INSTALL__"
+  [ "${with_spla}" = "__DONTUSE__" ] && with_spla="__INSTALL__"
+  [ "${with_gsl}" = "__DONTUSE__" ] && with_gsl="__INSTALL__"
+  [ "${with_libxc}" = "__DONTUSE__" ] && with_libxc="__INSTALL__"
+  [ "${with_fftw}" = "__DONTUSE__" ] && with_fftw="__INSTALL__"
+  [ "${with_spglib}" = "__DONTUSE__" ] && with_spglib="__INSTALL__"
+  [ "${with_hdf5}" = "__DONTUSE__" ] && with_hdf5="__INSTALL__"
+#  [ "${with_libvdwxc}" = "__DONTUSE__" ] && with_libvdwxc="__INSTALL__"
+#  [ "${with_cosma}" = "__DONTUSE__" ] && with_cosma="__INSTALL__"
 fi
 
-if [ "$with_plumed" = "__INSTALL__" ]; then
-  [ "$with_gsl" = "__DONTUSE__" ] && with_gsl="__INSTALL__"
-  [ "$with_fftw" = "__DONTUSE__" ] && with_fftw="__INSTALL__"
+if [ "${with_plumed}" = "__INSTALL__" ]; then
+  [ "${with_gsl}" = "__DONTUSE__" ] && with_gsl="__INSTALL__"
+  [ "${with_fftw}" = "__DONTUSE__" ] && with_fftw="__INSTALL__"
 fi
+
 # ------------------------------------------------------------------------
 # Preliminaries
 # ------------------------------------------------------------------------
 
-mkdir -p "$INSTALLDIR"
+mkdir -p ${INSTALLDIR}
 
 # variables used for generating cp2k ARCH file
-export CP_DFLAGS=''
-export CP_LIBS=''
-export CP_CFLAGS='-fopenmp'
+export CP_DFLAGS=""
+export CP_LIBS=""
+export CP_CFLAGS=""
 export CP_LDFLAGS="-Wl,--enable-new-dtags"
 
 # ------------------------------------------------------------------------
@@ -767,8 +813,10 @@ EOF
 
 # ------------------------------------------------------------------------
 # Special settings for CRAY Linux Environment (CLE)
+# TODO: CLE should be handle like gcc or Intel using a with_cray flag and
+#       this section should be moved to a separate file install_cray.
 # ------------------------------------------------------------------------
-if [ "$ENABLE_CRAY" = "__TRUE__" ]; then
+if [ "${ENABLE_CRAY}" = "__TRUE__" ]; then
   echo "------------------------------------------------------------------------"
   echo "CRAY Linux Environment (CLE) is detected"
   echo "------------------------------------------------------------------------"
@@ -778,16 +826,16 @@ if [ "$ENABLE_CRAY" = "__TRUE__" ]; then
   check_command cc
   check_command ftn
   check_command CC
-  export CC=cc
-  export FC=ftn
-  export F77=ftn
-  export F90=ftn
-  export CXX=CC
-  export MPICC=cc
-  export MPIFC=ftn
-  export MPIF77=ftn
-  export MPIF90=ftn
-  export MPICXX=CC
+  export CC="cc"
+  export CXX="CC"
+  export FC="ftn"
+  export F90="${FC}"
+  export F77="${FC}"
+  export MPICC="${CC}"
+  export MPICXX="${CXX}"
+  export MPIFC="${FC}"
+  export MPIF90="${MPIFC}"
+  export MPIF77="${MPIFC}"
   # CRAY libsci should contains core math libraries, scalapack
   # doesn't need LDFLAGS or CFLAGS, nor do the one need to
   # explicitly link the math and scalapack libraries, as all is
@@ -824,7 +872,8 @@ if [ "$ENABLE_CRAY" = "__TRUE__" ]; then
       ;;
     intelmpi)
       if [ "$with_intelmpi" = "__DONTUSE__" ]; then
-        with_gcc=__DONTUSE__
+        with_gcc="__DONTUSE__"
+        with_intel="__SYSTEM__"
         add_include_from_paths MPI_CFLAGS "mpi.h" $INCLUDE_PATHS
         add_include_from_paths MPI_LDFLAGS "libmpi.*" $LIB_PATHS
         export MPI_CFLAGS
@@ -849,63 +898,58 @@ fi
 
 echo "Compiling with $(get_nprocs) processes."
 
-# set environment for compiling compilers and tools required for CP2K
-# and libraries it depends on
-export CFLAGS=${CFLAGS:-"-O2 -g -Wno-error"}
-export FFLAGS=${FFLAGS:-"-O2 -g -Wno-error"}
-export FCLAGS=${FCLAGS:-"-O2 -g -Wno-error"}
-export F90FLAGS=${F90FLAGS:-"-O2 -g -Wno-error"}
-export F77FLAGS=${F77FLAGS:-"-O2 -g -Wno-error"}
-export CXXFLAGS=${CXXFLAGS:-"-O2 -g -Wno-error"}
-
 # Select the correct compute number based on the GPU architecture
-case $GPUVER in
+case ${GPUVER} in
   K20X)
-    export ARCH_NUM=35
+    export ARCH_NUM="35"
     ;;
   K40)
-    export ARCH_NUM=35
+    export ARCH_NUM="35"
     ;;
   K80)
-    export ARCH_NUM=37
+    export ARCH_NUM="37"
     ;;
   P100)
-    export ARCH_NUM=60
+    export ARCH_NUM="60"
     ;;
   V100)
-    export ARCH_NUM=70
+    export ARCH_NUM="70"
     ;;
   A100)
-    export ARCH_NUM=80
+    export ARCH_NUM="80"
+    ;;
+  Mi50)
+    # TODO: export ARCH_NUM=
+    ;;
+  Mi100)
+    # TODO: export ARCH_NUM=
     ;;
-  Mi50) ;;
-
-  Mi100) ;;
-
   no)
-    export ARCH_NUM=no
+    export ARCH_NUM="no"
     ;;
   *)
     report_error ${LINENO} \
-      "--gpu-ver currently only supports K20X, K40, K80, P100, V100, A100, Mi50, Mi100 as options"
+      "--gpu-ver currently only supports K20X, K40, K80, P100, V100, A100, Mi50, Mi100, and no as options"
+    exit 1
     ;;
 esac
 
-write_toolchain_env "${INSTALLDIR}"
+write_toolchain_env ${INSTALLDIR}
 
 # write toolchain config
-echo "tool_list=\"${tool_list}\"" > "${INSTALLDIR}"/toolchain.conf
-for ii in $package_list; do
+echo "tool_list=\"${tool_list}\"" > ${INSTALLDIR}/toolchain.conf
+for ii in ${package_list}; do
   install_mode="$(eval echo \${with_${ii}})"
-  echo "with_${ii}=\"${install_mode}\"" >> "${INSTALLDIR}"/toolchain.conf
+  echo "with_${ii}=\"${install_mode}\"" >> ${INSTALLDIR}/toolchain.conf
 done
 
 # ------------------------------------------------------------------------
 # Build packages unless dry-run mode is enabled.
 # ------------------------------------------------------------------------
-if [ "$dry_run" == "__TRUE__" ]; then
+if [ "${dry_run}" = "__TRUE__" ]; then
   echo "Wrote only configuration files (--dry-run)."
 else
+  echo "# Leak suppressions" > ${INSTALLDIR}/lsan.supp
   ./scripts/stage0/install_stage0.sh
   ./scripts/stage1/install_stage1.sh
   ./scripts/stage2/install_stage2.sh
@@ -916,7 +960,9 @@ else
   ./scripts/stage7/install_stage7.sh
   ./scripts/stage8/install_stage8.sh
   # Stage 9 is reserved for DBCSR.
-  ./scripts/generate_arch_files.sh
+  if [ "${no_arch_files}" = "__FALSE__" ]; then
+    ./scripts/generate_arch_files.sh
+  fi
 fi
 
 #EOF
