@@ -1,10 +1,7 @@
 # A set of tools used in the toolchain installer, intended to be used
 
 # TODO: Review and if possible fix shellcheck errors.
-# shellcheck disable=SC1003,SC1035,SC1083,SC1090
-# shellcheck disable=SC2001,SC2002,SC2005,SC2016,SC2091,SC2034,SC2046,SC2086,SC2089,SC2090
-# shellcheck disable=SC2124,SC2129,SC2144,SC2153,SC2154,SC2155,SC2163,SC2164,SC2166
-# shellcheck disable=SC2235,SC2237
+# shellcheck disable=all
 # shellcheck shell=bash
 
 # by sourcing this file inside other scripts.
@@ -144,7 +141,7 @@ reverse() (
 # get the number of processes available for compilation
 get_nprocs() {
   if [ -n "${NPROCS_OVERWRITE}" ]; then
-    echo "${NPROCS_OVERWRITE}"
+    echo ${NPROCS_OVERWRITE} | sed 's/^0*//'
   elif $(command -v nproc >&- 2>&-); then
     echo $(nproc --all)
   else
@@ -334,16 +331,16 @@ resolve_string() {
 
 # check if a command is available
 check_command() {
-  local __command=$1
+  local __command=${1}
   if [ $# -eq 1 ]; then
-    local __package=$1
+    local __package=${1}
   elif [ $# -gt 1 ]; then
-    local __package=$2
+    local __package=${2}
   fi
-  if $(command -v $__command >&- 2>&-); then
-    echo "path to $__command is " $(command -v $__command)
+  if $(command -v ${__command} >&- 2>&-); then
+    echo "path to ${__command} is $(command -v ${__command})"
   else
-    report_error "cannot find $__command, please check if $__package is installed or in system search path"
+    report_error "Cannot find ${__command}, please check if the package ${__package} is installed or in system search path"
     return 1
   fi
 }
@@ -359,6 +356,22 @@ check_dir() {
   fi
 }
 
+# check if a command has been installed correctly
+check_install() {
+  local __command=${1}
+  if [ $# -eq 1 ]; then
+    local __package=${1}
+  elif [ $# -gt 1 ]; then
+    local __package=${2}
+  fi
+  if $(command -v ${__command} >&- 2>&-); then
+    echo "$(basename ${__command}) is installed as $(command -v ${__command})"
+  else
+    report_error "cannot find ${__command}, please check if the package ${__package} has been installed correctly"
+    return 1
+  fi
+}
+
 # check if a library can be found by ld, library names should in the
 # format -lname, which would then referred to libname.a or libname.so
 # by ld
@@ -380,7 +393,7 @@ check_lib() {
   # instead of ld for linker then we can use LIBRARY_PATH, which IS
   # used during link stage. However, I think using ld is more
   # general, as in most systems LIBRARY_PATH is rarely defined, and
-  # we would have to reply on gcc.
+  # we would have to rely on gcc.
   local __search_engine="ld -o /dev/null"
   local __search_paths="$LIB_PATHS"
   # convert a list of paths to -L<dir> list used by ld
@@ -564,18 +577,22 @@ read_enable() {
 read_with() {
   local __input_var="${1#--with*=}"
   case $__input_var in
-    "$1")
+    "${1}")
       # if there is no "=" then treat as "install"
-      echo '__INSTALL__'
+      if [ ${#} -gt 1 ]; then
+        echo "${2}"
+      else
+        echo "__INSTALL__"
+      fi
       ;;
     install)
-      echo '__INSTALL__'
+      echo "__INSTALL__"
       ;;
     system)
-      echo '__SYSTEM__'
+      echo "__SYSTEM__"
       ;;
     no)
-      echo '__DONTUSE__'
+      echo "__DONTUSE__"
       ;;
     *)
       echo "${__input_var//\~/$HOME}"
